@@ -1,8 +1,6 @@
 """
 This file provides information of how to build and configure HepMC framework:
 https://gitlab.cern.ch/hepmc/HepMC3
-
-
 """
 
 import os
@@ -12,7 +10,6 @@ from edpm.engine.env_gen import Set, Append, Prepend
 from edpm.engine.git_cmake_recipe import GitCmakeRecipe
 
 
-
 class HepMC3Recipe(GitCmakeRecipe):
     """Provides data for building and installing HepMC framework
     source_path  = {app_path}/src/{version}          # Where the sources for the current version are located
@@ -30,20 +27,7 @@ class HepMC3Recipe(GitCmakeRecipe):
 
         self.config['branch'] = '3.2.5'
         self.config['repo_address'] = 'https://gitlab.cern.ch/hepmc/HepMC3.git'
-        self.config['cmake_flags'] = ' -DHEPMC3_ENABLE_ROOTIO=OFF -DHEPMC3_ENABLE_PYTHON=OFF -DHEPMC3_BUILD_EXAMPLES=ON'
-
-    def step_build(self):
-
-        super(HepMC3Recipe, self).step_build()
-
-        # To fix error such as tput: No value for $TERM and no -T specified
-        env('TERM', 'xterm')
-
-        # now copy convert_example.exe as HepMC3-convert in the bin folder
-        examples_dir = os.path.join(self.config['build_path'], 'outputs', 'bin')
-        exec_file_name = os.path.join(self.config['install_path'], 'bin', 'HepMC3-convert')
-        workdir(examples_dir)
-        run('mv convert_example.exe ' + exec_file_name)
+        self.config['cmake_flags'] = ' -DHEPMC3_ENABLE_ROOTIO=OFF -DHEPMC3_ENABLE_PYTHON=OFF -DHEPMC3_BUILD_EXAMPLES=OFF HEPMC3_CXX_STANDARD=17'
 
     @staticmethod
     def gen_env(data):
